# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('game', '0059_theme_name_data'),
    ]

    operations = [
        migrations.AlterField(
            model_name='level',
            name='theme',
            field=models.ForeignKey(db_column=b'theme_id', default=None, blank=True, to='game.Theme', null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Code for Life
#
# Copyright (C) 2016, Ocado Innovation Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ADDITIONAL TERMS – Section 7 GNU General Public Licence
#
# This licence does not grant any right, title or interest in any “Ocado” logos,
# trade names or the trademark “Ocado” or any other trademarks or domain names
# owned by Ocado Innovation Limited or the Ocado group of companies or any other
# distinctive brand features of “Ocado” as may be secured from time to time. You
# must not distribute any modification of this program using the trademark
# “Ocado” or claim any affiliation or association with Ocado or its employees.
#
# You are not authorised to use the name Ocado (or any of its trade names) or
# the names of any author or contributor in advertising or for publicity purposes
# pertaining to the distribution of this program, without the prior written
# authorisation of Ocado.
#
# Any propagation, distribution or conveyance of this program must include this
# copyright notice and these terms. You must not misrepresent the origins of this
# program; modified versions of the program must be marked as such and not
# identified as the original program.
import os
import socket
import time
from unittest import skipUnless

from django.core.urlresolvers import reverse
from django_selenium_clean import selenium, SeleniumTestCase

from . import custom_handler
from portal.models import UserProfile
from game.models import Workspace
from game.views.level import load_workspace_solution
from .game_page import GamePage
from portal.tests.pageObjects.portal.home_page import HomePage
from portal.tests.utils.organisation import create_organisation_directly
from portal.tests.utils.teacher import signup_teacher_directly
from portal.tests.utils.classes import create_class_directly
from portal.tests.utils.student import create_school_student_directly


custom_handler.monkey_patch()


@skipUnless(selenium, "Selenium is unconfigured")
class BaseGameTest(SeleniumTestCase):
    BLOCKLY_SOLUTIONS_DIR = os.path.join(os.path.dirname(__file__), 'data/blockly_solutions')

    already_logged_on = False
    user_profile = None

    def _go_to_path(self, path):
        socket.setdefaulttimeout(20)
        attempts = 0
        while True:
            try:
                selenium.get(self.live_server_url + path)
            except socket.timeout:
                attempts += 1
                if attempts > 2:
                    raise
                time.sleep(10)
            else:
                break

    def go_to_homepage(self):
        path = reverse('home')
        self._go_to_path(path)
        return HomePage(selenium)

    def go_to_level(self, level_name):
        path = reverse('play_default_level', kwargs={'levelName': str(level_name)})
        self._go_to_path(path)
        selenium.execute_script('ocargo.animation.FAST_ANIMATION_DURATION = 1;')

        return GamePage(selenium)

    def go_to_custom_level(self, level):
        path = reverse('play_custom_level', kwargs={'levelId': str(level.id)})
        self._go_to_path(path)
        selenium.execute_script('ocargo.animation.FAST_ANIMATION_DURATION = 1;')

        return GamePage(selenium)

    def go_to_episode(self, episodeId):
        path = reverse('start_episode', kwargs={'episodeId': str(episodeId)})
        self._go_to_path(path)
        selenium.execute_script('ocargo.animation.FAST_ANIMATION_DURATION = 1;')

        return GamePage(selenium)

    def deliver_everywhere_test(self, level):
        self.login_once()

        return self.go_to_level(level) \
            .solution_button() \
            .run_program()

    def try_again_if_not_full_score_test(self, level, workspace_file):
        user_profile = self.login_once()

        workspace_id = self.use_workspace(workspace_file, user_profile)

        return self.go_to_level(level) \
            .load_solution(workspace_id) \
            .run_retry_program()

    def run_crashing_test(self, level, workspace_file):
        user_profile = self.login_once()

        workspace_id = self.use_workspace(workspace_file, user_profile)

        return self.go_to_level(level) \
            .load_solution(workspace_id) \
            .run_crashing_program()

    def run_python_commands_test(self, level):
        return self.go_to_level(level) \
            .check_python_commands()

    def run_clear_console_test(self, level):
        return self.go_to_level(level) \
            .write_to_then_clear_console()

    def run_console_parse_error_test(self, level):
        return self.go_to_level(level) \
            .run_parse_error_program()

    def run_console_attribute_error_test(self, level):
        return self.go_to_level(level) \
            .run_attribute_error_program()

    def run_console_print_test(self, level):
        return self.go_to_level(level) \
            .run_print_program()

    def running_out_of_instructions_test(self, level, workspace_file):
        user_profile = self.login_once()

        workspace_id = self.use_workspace(workspace_file, user_profile)

        return self.go_to_level(level) \
            .load_solution(workspace_id) \
            .run_out_of_instructions_program()

    def running_out_of_fuel_test(self, level, workspace_file):
        user_profile = self.login_once()

        workspace_id = self.use_workspace(workspace_file, user_profile)

        return self.go_to_level(level) \
            .load_solution(workspace_id) \
            .run_out_of_fuel_program()

    def running_a_red_light_test(self, level, workspace_file):
        user_profile = self.login_once()

        workspace_id = self.use_workspace(workspace_file, user_profile)

        return self.go_to_level(level) \
            .load_solution(workspace_id) \
            .run_a_red_light_program()

    def not_delivered_everywhere_test(self, level, workspace_file):
        user_profile = self.login_once()

        workspace_id = self.use_workspace(workspace_file, user_profile)

        return self.go_to_level(level) \
            .load_solution(workspace_id) \
            .run_not_delivered_everywhere_program()

    def undefined_procedure_test(self, level, workspace_file):
        user_profile = self.login_once()

        workspace_id = self.use_workspace(workspace_file, user_profile)

        return self.go_to_level(level) \
            .load_solution(workspace_id) \
            .run_undefined_procedure_program()

    def use_workspace(self, workspace_file, user_profile):
        solution = self.read_solution(workspace_file)
        workspace_id = Workspace.objects.create(name=workspace_file, owner=user_profile, contents=solution).id
        return workspace_id

    def login_once(self):
        if not BaseGameTest.already_logged_on:
            email, password = signup_teacher_directly()
            create_organisation_directly(email)
            klass, name, access_code = create_class_directly(email)
            create_school_student_directly(access_code)
            self.go_to_homepage().go_to_login_page().login(email, password)
            email = email
            BaseGameTest.user_profile = UserProfile.objects.get(user__email=email)

            BaseGameTest.already_logged_on = True

        return BaseGameTest.user_profile

    def solution_file_path(self, filename):
        return os.path.join(BaseGameTest.BLOCKLY_SOLUTIONS_DIR, filename + ".xml")

    def read_solution(self, filename):
        path = self.solution_file_path(filename)
        if path:
            f = open(path, 'r')
            data = f.read()
            f.close()
        return data

    def _fixture_teardown(self):
        pass



# -*- coding: utf-8 -*-
# Code for Life
#
# Copyright (C) 2016, Ocado Innovation Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ADDITIONAL TERMS – Section 7 GNU General Public Licence
#
# This licence does not grant any right, title or interest in any “Ocado” logos,
# trade names or the trademark “Ocado” or any other trademarks or domain names
# owned by Ocado Innovation Limited or the Ocado group of companies or any other
# distinctive brand features of “Ocado” as may be secured from time to time. You
# must not distribute any modification of this program using the trademark
# “Ocado” or claim any affiliation or association with Ocado or its employees.
#
# You are not authorised to use the name Ocado (or any of its trade names) or
# the names of any author or contributor in advertising or for publicity purposes
# pertaining to the distribution of this program, without the prior written
# authorisation of Ocado.
#
# Any propagation, distribution or conveyance of this program must include this
# copyright notice and these terms. You must not misrepresent the origins of this
# program; modified versions of the program must be marked as such and not
# identified as the original program.
from game import messages
from game.messages import description_level_default, hint_level_default
from game.theme import get_theme, get_themes_url
from rest_framework import serializers
from models import Workspace, Level, Episode, LevelDecor, LevelBlock, Block


class WorkspaceSerializer(serializers.ModelSerializer):
    class Meta:
        model = Workspace


class LevelListSerializer(serializers.HyperlinkedModelSerializer):
    title = serializers.SerializerMethodField()

    class Meta:
        model = Level
        fields = ('url', '__unicode__', 'episode', 'name', 'title', 'default', 'blocklyEnabled', 'pythonEnabled')

    def get_title(self, obj):
        if obj.default:
            title = getattr(messages, 'title_level' + obj.name)()
            return title
        else:
            return "Custom Level"


class LevelDetailSerializer(serializers.HyperlinkedModelSerializer):
    title = serializers.SerializerMethodField()
    description = serializers.SerializerMethodField()
    hint = serializers.SerializerMethodField()
    levelblock_set = serializers.HyperlinkedIdentityField(
        view_name='levelblock-for-level',
        read_only=True
    )
    map = serializers.HyperlinkedIdentityField(
        view_name='map-for-level',
        read_only=True
    )
    mode = serializers.HyperlinkedIdentityField(
        view_name='mode-for-level',
        read_only=True
    )

    class Meta:
        model = Level
        fields = ('__unicode__', 'episode', 'name', 'title', 'description', 'hint', 'next_level', 'default',
                  'levelblock_set', 'map', 'mode', 'blocklyEnabled', 'pythonEnabled', 'pythonViewEnabled')

    def get_title(self, obj):
        if obj.default:
            title = getattr(messages, 'title_level' + obj.name)()
            return title
        else:
            return "Custom Level"

    def get_description(self, obj):
        if obj.default:
            description = getattr(messages, 'description_level' + obj.name)()
            return description
        else:
            return description_level_default()

    def get_hint(self, obj):
        if obj.default:
            hint = getattr(messages, 'hint_level' + obj.name)()
            return hint
        else:
            return hint_level_default()

    def get_leveldecor_set(self, obj):
        leveldecors = LevelDecor.objects.filter(level__id=obj.id)
        serializer = LevelDecorSerializer(leveldecors, many=True, context={'request': self.context.get('request', None)})
        return serializer.data


class LevelModeSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = Level
        fields = ('blocklyEnabled', 'pythonEnabled', 'pythonViewEnabled')


class LevelMapListSerializer(serializers.HyperlinkedModelSerializer):
    url = serializers.HyperlinkedIdentityField(
        view_name='map-for-level',
        read_only=True
    )

    class Meta:
        model = Level
        fields = ('url',)


class LevelMapDetailSerializer(serializers.HyperlinkedModelSerializer):
    leveldecor_set = serializers.SerializerMethodField()
    theme = serializers.SerializerMethodField()

    class Meta:
        model = Level
        fields = ('origin', 'destinations', 'path', 'traffic_lights', 'max_fuel', 'theme', 'leveldecor_set')

    def get_leveldecor_set(self, obj):
        leveldecors = LevelDecor.objects.filter(level__id=obj.id)
        serializer = LevelDecorSerializer(leveldecors, many=True, context={'request': self.context.get('request', None)})
        return serializer.data

    def get_theme(self, obj):
        pk = get_theme(obj.theme_name).pk
        return get_themes_url(pk, self.context.get('request', None))


class EpisodeListSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = Episode
        fields = ('url', '__unicode__', 'name')


class EpisodeDetailSerializer(serializers.HyperlinkedModelSerializer):
    level_set = serializers.SerializerMethodField()
    level_set_url = serializers.HyperlinkedIdentityField(view_name='level-for-episode',
                                                          read_only=True)

    class Meta:
        model = Episode
        depth = 1
        fields = ('url', '__unicode__', 'name', 'level_set', 'level_set_url')

    def get_level_set(self, obj):
        levels = Level.objects.filter(episode__id=obj.id)
        serializer = LevelListSerializer(levels, many=True, context={'request': self.context.get('request', None)})
        return serializer.data


class LevelBlockSerializer(serializers.ModelSerializer):
    class Meta:
        model = LevelBlock


class LevelDecorSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = LevelDecor


class BlockSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = Block
        fields = ('url', 'id', 'type')



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('game', '0057_workspace_language_enabled'),
    ]

    operations = [
        migrations.AddField(
            model_name='level',
            name='theme_name',
            field=models.CharField(
                default=None,
                max_length=10,
                null=True,
                blank=True,
                choices=[('farm', 'farm'), ('city', 'city'), ('grass', 'grass'), ('snow', 'snow')],
            ),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('game', '0062_rm_old_theme_decor_models'),
    ]

    operations = [
        migrations.AddField(
            model_name='level',
            name='character_name',
            field=models.CharField(
                    default=None,
                    max_length=20,
                    null=True,
                    blank=True,
                    choices=[('Nigel', 'Nigel'), ('Kirsty', 'Kirsty'), ('Phil', 'Phil'), ('Wes', 'Wes'), ('Van', 'Van'), ('Dee', 'Dee')]),
        ),
    ]



# -*- coding: utf-8 -*-
# Code for Life
#
# Copyright (C) 2016, Ocado Innovation Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ADDITIONAL TERMS – Section 7 GNU General Public Licence
#
# This licence does not grant any right, title or interest in any “Ocado” logos,
# trade names or the trademark “Ocado” or any other trademarks or domain names
# owned by Ocado Innovation Limited or the Ocado group of companies or any other
# distinctive brand features of “Ocado” as may be secured from time to time. You
# must not distribute any modification of this program using the trademark
# “Ocado” or claim any affiliation or association with Ocado or its employees.
#
# You are not authorised to use the name Ocado (or any of its trade names) or
# the names of any author or contributor in advertising or for publicity purposes
# pertaining to the distribution of this program, without the prior written
# authorisation of Ocado.
#
# Any propagation, distribution or conveyance of this program must include this
# copyright notice and these terms. You must not misrepresent the origins of this
# program; modified versions of the program must be marked as such and not
# identified as the original program.
from __future__ import unicode_literals

from django.db import migrations
from game.level_management import set_decor_inner, set_blocks_inner
import json


def change_levels(apps, schema_editor):

    Level = apps.get_model('game', 'Level')
    LevelDecor = apps.get_model('game', 'LevelDecor')
    LevelBlock = apps.get_model('game', 'LevelBlock')
    Block = apps.get_model('game', 'Block')

    def set_decor(level, decor):
        set_decor_inner(level, decor, LevelDecor)

    def set_blocks(level, blocks):
        set_blocks_inner(level, blocks, LevelBlock, Block)

    level61 = Level.objects.get(name='61', default=1)
    level61.model_solution = '[9]'
    level61.save()

    level75 = Level.objects.get(name='75', default=1)
    level73 = Level.objects.get(name='73', default=1)
    level72 = Level.objects.get(name='72', default=1)
    level74 = Level.objects.get(name='74', default=1)
    level79 = Level.objects.get(name='79', default=1)

    level72.next_level = level75
    level75.next_level = level74
    level74.next_level = level73
    level73.next_level = level79
    level79.next_level = None

    level74.path = ('[{"coordinate":[9,2],"connectedNodes":[1]},' +
                    '{"coordinate":[8,2],"connectedNodes":[2,9,0]},' +
                    '{"coordinate":[7,2],"connectedNodes":[1,3]},' +
                    '{"coordinate":[7,1],"connectedNodes":[4,2]},' +
                    '{"coordinate":[6,1],"connectedNodes":[5,3,6]},' +
                    '{"coordinate":[5,1],"connectedNodes":[8,4,34]},' +
                    '{"coordinate":[6,0],"connectedNodes":[4]},' +
                    '{"coordinate":[3,2],"connectedNodes":[28,37,35]},' +
                    '{"coordinate":[4,1],"connectedNodes":[35,5]},' +
                    '{"coordinate":[8,3],"connectedNodes":[10,1]},' +
                    '{"coordinate":[8,4],"connectedNodes":[11,9]},' +
                    '{"coordinate":[8,5],"connectedNodes":[12,33,10]},' +
                    '{"coordinate":[8,6],"connectedNodes":[13,11]},' +
                    '{"coordinate":[7,6],"connectedNodes":[14,12]},' +
                    '{"coordinate":[6,6],"connectedNodes":[15,13]},' +
                    '{"coordinate":[5,6],"connectedNodes":[16,14,29]},' +
                    '{"coordinate":[4,6],"connectedNodes":[17,15,39]},' +
                    '{"coordinate":[3,6],"connectedNodes":[18,16]},' +
                    '{"coordinate":[2,6],"connectedNodes":[19,30,17]},' +
                    '{"coordinate":[1,6],"connectedNodes":[20,18]},' +
                    '{"coordinate":[0,6],"connectedNodes":[19,21]},' +
                    '{"coordinate":[0,5],"connectedNodes":[20,22]},' +
                    '{"coordinate":[0,4],"connectedNodes":[21,31,23]},' +
                    '{"coordinate":[0,3],"connectedNodes":[22,24]},' +
                    '{"coordinate":[0,2],"connectedNodes":[23,25]},' +
                    '{"coordinate":[0,1],"connectedNodes":[24,26]},' +
                    '{"coordinate":[1,1],"connectedNodes":[25,27,32]},' +
                    '{"coordinate":[2,1],"connectedNodes":[26,28]},' +
                    '{"coordinate":[2,2],"connectedNodes":[7,27]},' +
                    '{"coordinate":[5,5],"connectedNodes":[15]},' +
                    '{"coordinate":[2,7],"connectedNodes":[18]},' +
                    '{"coordinate":[1,4],"connectedNodes":[22]},' +
                    '{"coordinate":[1,0],"connectedNodes":[26]},' +
                    '{"coordinate":[9,5],"connectedNodes":[11]},' +
                    '{"coordinate":[5,0],"connectedNodes":[5]},' +
                    '{"coordinate":[4,2],"connectedNodes":[7,36,8]},' +
                    '{"coordinate":[4,3],"connectedNodes":[37,38,35]},' +
                    '{"coordinate":[3,3],"connectedNodes":[36,7]},' +
                    '{"coordinate":[4,4],"connectedNodes":[39,36]},' +
                    '{"coordinate":[4,5],"connectedNodes":[40,16,38]},' +
                    '{"coordinate":[3,5],"connectedNodes":[41,39]},' +
                    '{"coordinate":[2,5],"connectedNodes":[40,42]},' +
                    '{"coordinate":[2,4],"connectedNodes":[41]}]')
    level74.traffic_lights = '[]'
    level74.destinations = '[[2,4]]'
    level74.origin = '{"coordinate":[9,2],"direction":"W"}'
    level74.model_solution = '[13]'

    level74.save()

    LevelDecor.objects.filter(level=level74).delete()

    set_decor(level74, json.loads('[{"x":738,"y":33,"decorName":"tree1"},' +
                                  '{"x":496,"y":404,"decorName":"tree2"},' +
                                  '{"x":248,"y":39,"decorName":"pond"},' +
                                  '{"x":101,"y":500,"decorName":"bush"},' +
                                  '{"x":148,"y":561,"decorName":"bush"},' +
                                  '{"x":97,"y":565,"decorName":"bush"}]'))
    set_blocks(level74, json.loads('[{"type":"move_forwards","number":1},' +
                                   '{"type":"turn_left","number":2},' +
                                   '{"type":"turn_right","number":1},' +
                                   '{"type":"turn_around","number":2},' +
                                   '{"type":"controls_repeat","number":1},' +
                                   '{"type":"call_proc"},{"type":"declare_proc"}]'))

    level73.model_solution = '[15]'
    level75.model_solution = '[10, 26]'

    level75.name = '73'
    level73.name = '75'

    level72.save()
    level75.save()
    level74.save()
    level73.save()
    level79.save()

    level88 = Level.objects.get(name='88', default=1)
    levelBlock = LevelBlock(level=level88, type=Block.objects.get(type='wait'))
    levelBlock.save()

    level89 = Level.objects.get(name='89', default=1)
    levelBlock = LevelBlock(level=level89, type=Block.objects.get(type='logic_negate'))
    levelBlock.save()

    levelBlock = LevelBlock.objects.get(type=Block.objects.get(type='controls_repeat_until'),
                                        level=level89)
    levelBlock.delete()

    level90 = Level.objects.get(name='90', default=1)
    level90.path = ('[{"coordinate":[1,6],"connectedNodes":[1]},' +
                    '{"coordinate":[2,6],"connectedNodes":[0,2]},' +
                    '{"coordinate":[2,5],"connectedNodes":[1,3]},' +
                    '{"coordinate":[3,5],"connectedNodes":[2,4]},' +
                    '{"coordinate":[4,5],"connectedNodes":[3,5]},' +
                    '{"coordinate":[4,4],"connectedNodes":[4,6]},' +
                    '{"coordinate":[5,4],"connectedNodes":[5,7]},' +
                    '{"coordinate":[5,3],"connectedNodes":[6,8]},' +
                    '{"coordinate":[6,3],"connectedNodes":[7,9]},' +
                    '{"coordinate":[7,3],"connectedNodes":[8,10]},' +
                    '{"coordinate":[7,2],"connectedNodes":[9,11]},' +
                    '{"coordinate":[8,2],"connectedNodes":[10,12]},' +
                    '{"coordinate":[8,1],"connectedNodes":[13,11]},' +
                    '{"coordinate":[7,1],"connectedNodes":[14,12]},' +
                    '{"coordinate":[6,1],"connectedNodes":[15,13]},' +
                    '{"coordinate":[5,1],"connectedNodes":[16,14]},' +
                    '{"coordinate":[4,1],"connectedNodes":[17,15]},' +
                    '{"coordinate":[3,1],"connectedNodes":[18,16]},' +
                    '{"coordinate":[3,2],"connectedNodes":[19,17]},' +
                    '{"coordinate":[2,2],"connectedNodes":[20,18]},' +
                    '{"coordinate":[2,3],"connectedNodes":[21,19]},' +
                    '{"coordinate":[1,3],"connectedNodes":[22,20]},' +
                    '{"coordinate":[1,4],"connectedNodes":[23,21]},' +
                    '{"coordinate":[0,4],"connectedNodes":[22]}]')
    level90.destinations = '[[0,4]]'
    level90.save()

    level101 = Level.objects.get(name='101', default=1)
    level101.blocklyEnabled = False
    level101.save()

    level105 = Level.objects.get(name='105', default=1)
    Level.objects.filter(name='106', default=1).exclude(pk=level105.next_level.id).delete()

    level106 = Level.objects.get(name='106', default=1)
    Level.objects.filter(name='107', default=1).exclude(pk=level106.next_level.id).delete()


class Migration(migrations.Migration):

    dependencies = [
        ('game', '0001_squashed_0025_levels_ordering_pt1'),
    ]

    operations = [
        migrations.RunPython(change_levels)
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('game', '0065_rename_old_character_field'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='level',
            name='character_old',
        ),
        migrations.DeleteModel(
            name='Character',
        ),
    ]



# -*- coding: utf-8 -*-
from setuptools import find_packages, setup
import versioneer

setup(name='rapid-router',
    cmdclass=versioneer.get_cmdclass(),
    packages=find_packages(),
    include_package_data=True,
    install_requires = [
        'django==1.8.2',
        'django-foundation-icons==3.1',
        'django-bourbon==3.1.8',
        'django-autoconfig==0.3.6',
        'django-jquery==1.9.1',
        'django-js-reverse==0.6.1',
        'django-foundation-statics==5.4.7',
        'django-pipeline==1.5.4',
        'django-appconf==1.0.1',
        'django-casper==0.0.3',
        'djangorestframework==3.1.3',
        'six==1.9.0',
        'docutils==0.12',
        'pyhamcrest==1.8.3',
    ],
    tests_require=[
        'django-setuptest',
        'django-selenium-clean==0.2.1',
        'selenium==3.7.0',
    ],
    test_suite='setuptest.setuptest.SetupTestSuite',
    version=versioneer.get_version(),
    zip_safe=False,
)
